import Taro, { Component } from '@tarojs/taro';
import { ScrollView, View, Block } from '@tarojs/components';
import { TaroCanvasDrawer } from '@components/taro-plugin-canvas';
import { getCanvasConfig } from './util';
import './style.scss';

export default class Poster extends Component {
  state = {
    images: [],
    current: undefined,
    configs: undefined,
  }

  componentWillMount() {
    if (!Array.isArray(this.props.tpls)) {
      throw new Error('当前内容未维护海报信息')
    }

    let configs = this.state.configs || []
    this.props.tpls.forEach((tpl, inx) => {
      const conf = getCanvasConfig(tpl.configs, this.props.params)
      configs.push(conf)

      if (inx === this.props.tpls.length - 1) {
        this.setState({ configs })
      }
    })
  }

  onScroll = inx => (e) => {
    this.setState({ current: this.state.images[inx] })
  }

  onPreview = (e) => {
    e.stopPropagation()
    e.preventDefault()
    Taro.previewImage({
      current: this.state.current,
      urls: this.state.images
    })
  }

  onCancel = () => {
    if (typeof this.props.onCancel === 'function') {
      this.props.onCancel()
    }
  }

  saveToAlbum = (e) => {
    e.stopPropagation()
    e.preventDefault()

    if (!this.state.current) {
      return
    }

    Taro.authorize({ scope: "scope.writePhotosAlbum" }).then(res => {
      Taro.saveImageToPhotosAlbum({
        filePath: this.state.current,
      }).then(res => {
        if (typeof this.props.onFinish === 'function') {
          this.props.onFinish()
        }

        Taro.showToast({
          title: '保存图片成功',
          icon: 'success',
          duration: 2000,
        });
      })
    }).catch(err => {
      console.log('err:', err)
      Taro.showToast({
        title: '未开启相册权限',
        icon: 'none'
      })
    })
  }

  onCreateSuccess = (inx) => (result) => {
    if (inx + 1 === this.props.tpls.length) {
      Taro.hideLoading();
    }

    let images = this.state.images || []
    const { tempFilePath, errMsg } = result;
    if (errMsg === 'canvasToTempFilePath:ok') {
      images[inx] = tempFilePath
    } else {
      images[inx] = undefined
      console.log(errMsg);
    }
    this.setState({ images });
  }

  onCreateFail = (inx) => (err) => {
    if (inx + 1 === this.props.tpls.length) {
      Taro.hideLoading();
    }

    let images = this.state.images || []
    images[inx] = undefined
    this.setState({ images });
    console.err(err);
  }

  render() {
    const {
      images,
      configs
    } = this.state

    return (
      <View className="poster">
        <View className="con">
          <View className="con-head">
            <Text>保存后分享图片</Text>
            <Text className="iconfont icon-buoumaotubiao20" onClick={this.onCancel}></Text>
          </View>
          <View className="con-body">
            {
              images.map((img, inx) => {
                return (
                  <ScrollView scrollX scrollWithAnimation onScroll={this.onScroll(inx)} style="width: 100%" key={`img-${inx}`}>
                    <Image className="result-img" mode="aspectFit" lazy-load src={img} onClick={this.onPreview}></Image>
                  </ScrollView>
                )
              })
            }
          </View>
          <Button className="save-btn" onClick={this.saveToAlbum}>保存海报</Button>
        </View>
        {
          configs &&
          (
            configs.map((conf, inx) => {
              return (
                <Block key={`cvs-${inx}`}>
                  {
                    !images[inx] && (
                      <TaroCanvasDrawer
                        config={conf}
                        onCreateSuccess={this.onCreateSuccess(inx)}
                        onCreateFail={this.onCreateFail(inx)}
                      />
                    )
                  }
                </Block>
              )
            })
          )
        }
      </View>
    );
  }
}
