import Taro, { Component } from '@tarojs/taro'
import { postFormId } from '@services/card'

/**
 * 微信小程序 FormId 收集器。
 *
 * @example
 *
 * ```jsx
 * <MFormIdCollector
 *   count={5}
 *   onCollect={formIds => console.log(formIds)}>
 *   <View>任意内容</View>
 * </MFormIdCollector>
 * ```
 */
export default class Index extends Component {
  static defaultProps = {
    count: 7,
    disabled: false,
    onCollect: function () { }
  }

  state = {
    formIds: []
  }

  handleCollect = e => {
    let { formIds } = this.state
    const { onCollect, count } = this.props
    formIds.push(e.detail.formId)
    if (formIds.length === count) {
      onCollect(formIds.slice())

      // 发送到服务器
      postFormId({ formids: formIds })
      formIds = []
    }
    this.setState({
      formIds
    })
  }

  render() {
    const { count, disabled } = this.props
    const finalCount = Math.min(count, 7)

    return (disabled || finalCount === 0) ? this.props.children : (
      <Block>
        <Label for='button_6'>
          <Label for='button_5'>
            <Label for='button_4'>
              <Label for='button_3'>
                <Label for='button_2'>
                  <Label for='button_1'>
                    <Label for='button_0'>
                      {this.props.children}
                    </Label>
                  </Label>
                </Label>
              </Label>
            </Label>
          </Label>
        </Label>
        {[1,2,3,4].map(i => (
          <Form
            key={i}
            className='m-form-id-collector_form'
            reportSubmit={true}
            onSubmit={this.handleCollect}>
            <Button
              id={`button_${i}`}
              formType='submit'
            />
          </Form>
        ))}
      </Block>
    )
  }
}