import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import Notice from '@components/Notice'
// import BackHomeBtn from '@components/BackHomeBtn'
import AchievePhone from '@components/achievePhone'
import Poster from '@components/Poster'
import dayjs from 'dayjs'
// import WxParse from '@components/wxParse/wxParse'
// import getUserPhone from '@utils/getUserPhone'
import ready from '@utils/ready'
import { getDownloadURL, times, formateLeftTime } from '@utils/tools'
import {
  getGroupDetail,
  createGroupActivity,
  joinGroupBuy,
} from '@services/activity'
import {
  getMiniQrcode,
  savePoint,
  updatePoint
} from '@services/common'
import { connect } from '@tarojs/redux'

const waitImg = require('@assets/helpgroup/wait.png')
const memberImg = require('@assets/helpgroup/group/member.png')
const successImg = require('@assets/helpgroup/group/success.png')
const failImg = require('@assets/helpgroup/group/fail.png')

// 活动状态
const ActBeforeStart = 0;
const ActInProcess = 1;
const ActFinished = 2;

// 发起的拼团状态
const GroupInProcess = 1;
const GroupSuccess = 0;
const GroupFailure = 2;

@connect(state => state.user)
export default class Detail extends Component {
  config = {
    navigationBarTitleText: '拼团详情'
  }

  state = {
    id: null, // 活动ID
    recordId: undefined,  // 发起拼团ID
    loaded: false,
    detail: {}, // 活动详情
    recordDetail: {}, // 发团记录
    memberList: [], // 团员记录
    shares: [], // 分享设置
    posters: [], // 海报模板
    leftTime: 0,  // 剩余时间
    ltTicker: undefined,  // 剩余时间计时器
    actState: ActBeforeStart,  // 活动本身状态
    groupState: GroupInProcess, // 发起拼团活动的状态
    isStarter: true, // 是否发起人
    submitting: false, // 是否提交中
    actionSheetVisible: false, // 底部分享好友
    posterVisible: false, // 海报分享
    grantPhoneVisible: false, // 授权电话
    grantAvatarVisible: false, // 授权头像
  }

  componentWillMount() {
    ready.queue(() => {
      // 必须授权电话
      if (this.toggleGrantPhone()) {
        this.initPageData()
      }
    })
  }

  componentWillUnmount() {
    this.clearTicker()
  }

  // 初始化页面数据
  initPageData = () => {
    if (!this.state.detail.groupActivityId) {
      let id = this.$router.params.id
      let recordId = this.$router.params.recordId
     
      if (!id) {
        const router = Taro.getStorageSync('router')
        id = router.query.id
        recordId = router.query.recordId
      }

      this.setState({ id, recordId }, () => {
        this.loadDetail()
      })
    }
  }

  // 清除 ticker
  clearTicker() {
    if (this.state.ltTicker) {
      clearInterval(this.state.ltTicker)
      this.setState({ ltTicker: undefined })
    }
  }

  // 调起授权电话
  toggleGrantPhone = () => {
    const { userInfo: { person: { phone } } } = this.props
    if (!phone) {
      this.setState({ grantPhoneVisible: true })
      return false
    }

    return true
  }

  // 调起授权头像
  toggleGrantAvatar = () => {
    const { userInfo: { person: { avatarurl } } } = this.props
    if (!avatarurl) {
      this.setState({ grantAvatarVisible: true })
      return false
    }

    return true
  }

  // 打开关闭 ActionSheet 面板
  toggleActionVisible = () => {
    this.setState({
      actionSheetVisible: !this.state.actionSheetVisible
    })
  }

  // 打开关闭海报面板
  togglePosterVisible = () => {
    this.setState({
      posterVisible: !this.state.posterVisible,
      actionSheetVisible: false
    })
  }

  compActState = (startDate, endDate) => {
    const st = dayjs(startDate).valueOf()
    const ed = dayjs(endDate).valueOf()
    const nw = dayjs().valueOf()

    if (st > nw) {
      // 活动未开始
      return [ActBeforeStart, st - nw]
    } else if (ed > nw) {
      // 活动进行中
      return [ActInProcess, ed - nw]
    } else {
      // 活动已结束
      return [ActFinished, 0]
    }
  }

  // 计时器更新剩余时间
  updateLeftTime(startDate, endDate) {
    this.setState({
      ltTicker: setInterval(() => {
        const [actState, leftTime] = this.compActState(startDate, endDate)
        this.setState({ actState, leftTime })

        if (actState === ActFinished) {
          this.clearTicker()
        }
      }, 1000)
    })
  }

  loadDetail() {
    const { id, recordId } = this.state
    const { userInfo } = this.props

    Taro.showLoading()
    getGroupDetail(id, recordId).then(res => {
      this.clearTicker()

      const recordDetail = res.taShareRecord || {}
      let [actState, leftTime] = this.compActState(res.taShareActivity.startTime, res.taShareActivity.endTime)

      if (res.taShareActivity.status != 1) {
        actState = ActFinished
      }

      Taro.hideLoading()
      this.setState({
        detail: res.taShareActivity,
        recordDetail,
        recordId: recordDetail.recordId,
        groupState: recordDetail.status === undefined ? GroupInProcess : recordDetail.status,
        shares: res.shareContentList || [],
        posters: res.postList || [],
        posterTpls: res.posterTemplateList || [],
        memberList: res.shareChildRecordList || [],
        loaded: true,
        isStarter: !recordDetail.personId || userInfo.person.personId === recordDetail.personId,
        actState,
        leftTime,
      })

      if (actState != ActFinished) {
        this.updateLeftTime(res.taShareActivity.startTime, res.taShareActivity.endTime)
      }

      Taro.setNavigationBarTitle({ title: res.taShareActivity.activityName })

      // WxParse.wxParse('article', 'html', res.desc, this.$scope, 0)

      // savePoint({
      //   event: 'detail',
      //   eventType: 'group',
      //   propertyName: '拼团详情',
      //   buildingId: res.buildingId,
      //   targetId: res.groupActivityId,
      //   data: '{}'
      // }).then(res1 => {
      //   this.setState({
      //     recordId: res1.recordId
      //   })
      // })
    })
  }

  currentPageAndParams() {
    const { id, recordId } = this.state
    const { userInfo: { person: { personId } } } = this.props

    let queryParams = [
      `id=${id}`,
      `from=group_share`,
      `recommender=${personId}`
    ]
    if (recordId) {
      queryParams.push(`recordId=${recordId}`)
    }

    const res = [
      'pages/activity/detail/assemble',
      queryParams.join('&'),
    ]

    console.log('--page-params->', res)
    return res
  }


  onShareAppMessage = () => {
    const { shares } = this.state
    const currentPage = this.currentPageAndParams().join('?')

    savePoint({
      event: 'share',
      eventType: 'group',
      propertyName: '拼团详情分享',
      data: '{}'
    })

    if (!shares || !shares.length) {
      return {
        title: this.state.detail.activityName,
        path: currentPage,//分享地址
        imageUrl: this.state.detail.mainImg
      }
    }

    return {
      title: shares[0].shareContentTitle,
      path: currentPage,//分享地址
      imageUrl: shares[0].shareContentImg
    }
  }

  // 立即参团
  joinGroup = () => {
    if (this.state.submitting) return

    Taro.showLoading()
    this.setState({ submitting: true }, () => {
      const { detail, recordDetail } = this.state
      const person = this.props.userInfo.person

      joinGroupBuy({
        recordId: recordDetail.recordId,
        groupActivityId: detail.groupActivityId,
        personId: person.personId,
        nickname: person.name || person.nickname,
        phone: person.tel || person.phone,
        avatarurl: person.avatarurl,
      }).then((res) => {
        Taro.hideLoading()
        const memberList = this.state.memberList || []
        memberList.push(res.taShareChildRecord)

        this.setState({
          submitting: false,
          memberList,
          recordDetail: res.taShareRecord,
          recordId: res.taShareRecord.recordId,
          groupState: res.taShareRecord.status === undefined ? GroupInProcess : res.taShareRecord.status,
        })

        Taro.showToast({
          title: '参团成功',
          icon: 'success'
        })
      }).catch(err => {
        console.log('err:', err)
        Taro.hideLoading()

        Taro.showToast({
          title: '失败: ' + err.message,
          icon: 'none'
        })

        this.setState({ submitting: false })
      })
    })
  }

  // 发起我的拼团
  startMine = () => {
    // 必须授权头像
    if (this.toggleGrantAvatar()) {
      const detail = this.state.detail
      const person = this.props.userInfo.person

      return new Promise((resolve, reject) => {
        createGroupActivity({
          groupActivityId: detail.groupActivityId,
          personId: person.personId,
          nickname: person.name || person.nickname,
          phone: person.tel || person.phone,
          avatarurl: person.avatarurl,
        }).then(res => {
          this.setState({
            recordDetail: res,
            recordId: res.recordId,
            memberList: [],
            isStarter: true,
            groupState: GroupInProcess,
          }, resolve)
        }).catch(err => {
          console.log('err:', err)
          Taro.showToast({
            title: '发起失败: ' + err.message,
            icon: 'none'
          })
          reject()
        })
      })
    }

    return Promise.reject()
  }

  // 请求好友参团
  groupBuyInvite = () => {
    // 必须授权头像
    if (this.toggleGrantAvatar()) {
      const recordDetail = this.state.recordDetail
      if (!recordDetail.recordId) {
        // 如果是未发起的拼团, 先以当前人身份发起
        this.startMine().then(() => {
          this.toggleActionVisible()
        })
      } else {
        this.toggleActionVisible()
      }
    }
  }

  getQRCode() {
    const [page, scene] = this.currentPageAndParams()
    const payload = { page, scene }

    getMiniQrcode(payload).then(qrCode => {
      this.setState({ qrCode, posterVisible: true })
    })
  }

  // 发送朋友圈
  shareMoments = () => {
    this.getQRCode().then(() => {
      this.togglePosterVisible()
    })
  }

  render() {
    const {
      recordId,
      recordDetail,
      detail,
      loaded,
      actState,
      posterVisible,
      isStarter,
      memberList,
      groupState,
      actionSheetVisible,
      grantPhoneVisible,
      posterTpls,
      posters,
      qrCode,
      leftTime,
    } = this.state

    const { userInfo } = this.props
    const posterData = {
      title: posters[0] ? posters[0].posterTitle : '',
      desc: posters[0] ? posters[0].posterDescription : '',
      poster: posters[0] ? posters[0].posterImg : '',
      name: userInfo.person.name || userInfo.person.nickname,
      qrcode: qrCode,
      avatarurl: getDownloadURL(userInfo.person.avatarurl, 'avatar') || '',
    }

    // 团长显示团长核销码, 参团的显示参团核销码
    const verificationCode = isStarter ? recordDetail.verificationCode : (memberList.filter(x => x.personId === userInfo.person.personId)[0] || {}).verificationCode

    const joinedNum = detail.groupBuyPeople - (recordDetail.recordId ? 1 : 0) - memberList.length

    return (
      <Block>
        {/* 生成海报 */}
        {posterVisible && (<Poster tpls={posterTpls} params={posterData} onCancel={this.togglePosterVisible} onFinish={this.togglePosterVisible}></Poster>)}

        {
          grantPhoneVisible &&
          <AchievePhone user={userInfo.person} onSuccess={this.initPageData}></AchievePhone>
        }

        {
          loaded && (
            <View className="ass-page">
              <Notice></Notice>
              <View className="detail-banner">
                <Image mode="widthFix" src={detail.mainImg} className="detail-banner__img"></Image>

                <View className="rest-time">
                  <Text className="row-label">{actState === ActBeforeStart ? '距活动开始 :' : (actState === ActInProcess ? '活动剩余时间 :' : '')} </Text>
                  <Text className="row-content">{actState != ActFinished ? formateLeftTime(leftTime) : '活动已结束'}</Text>
                </View>
                {detail.successNum > 0 &&
                  <View className="success-num">
                    <View className="triangle"></View>
                    <View className="text">已成功 {detail.successNum}</View>
                  </View>
                }
              </View>
              <ScrollView
                scrollY
                className="detail-wrap">
                <View className="detail">
                  <View class="detail-title">{detail.activityName}</View>
                  <View className="detail-info" >
                    <View style="margin-right:30px">所需<Text style="color:#FF245A">{detail.integral}</Text>积分</View>
                    <Image style="width:20px;height:20px;margin-right:2px" src={memberImg} ></Image>
                    <Text >{detail.groupBuyPeople}人团</Text>
                  </View>
                  {
                    groupState === GroupSuccess &&
                    (
                      <Block>
                        <Image className="status__img" style="margin:12rpx auto 24rpx auto" src={successImg}></Image>
                        <View className="hexiaoma" style="margin:0 auto 40rpx auto">核销码: {verificationCode}</View>
                      </Block>
                    )
                  }

                  {
                    groupState === GroupFailure &&
                    (
                      <View>
                        <Image className="status__img" style="margin:12rpx auto 24rpx auto" src={failImg}></Image>
                        <View className="fail-text" style="margin:0 auto 40rpx auto">活动已超时,拼团失败!</View>
                      </View>
                    )
                  }

                  {isStarter &&
                    <View className="detail-title" >我的拼团</View>
                  }

                  <View className='tools-main'>
                    {
                      recordDetail.recordId &&
                      (
                        <View className='tools-item'>
                          <Image src={recordDetail.avatarurl} className='tools-item-img'></Image>
                          <View className='leader-tip'>团长</View>
                          <Text className='tools-item-txt'>{recordDetail.nickname}</Text>
                        </View>
                      )
                    }
                    {
                      memberList.map((it, inx) => {
                        return (
                          <View className='tools-item' key={`group-${inx}`}>
                            <Image src={it.avatarurl} className='tools-item-img'></Image>
                            <Text className='tools-item-txt'>{it.nickname}</Text>
                          </View>
                        )
                      })
                    }
                    {
                      times(joinedNum).map((_, inx) => {
                        return (
                          <View className='tools-item' key={`un-${inx}`}>
                            <Image src={waitImg} className='tools-item-img'></Image>
                            <Text className='wait-txt'>等待拼团</Text>
                          </View>
                        )
                      })
                    }
                  </View>
                </View>

                <View className="assistance-text"><Text style="color:#dcdcdc">------------------- </Text><Text className="acitivty-desc">活动说明</Text><Text style="color:#dcdcdc">-------------------</Text></View>
                <View style="padding:0 40rpx">
                  <Image src={detail.descImg} style="width:100%"></Image>
                </View>

                {
                  actState === ActBeforeStart &&
                  (<Button className="nostart-btn" style="margin:36px auto">未开始</Button>)
                }
                {
                  isStarter && actState === ActInProcess && groupState === GroupInProcess &&
                  (<Button className="assistance-btn" style="margin:36px auto" onClick={this.groupBuyInvite}>邀请好友拼团</Button>)
                }
                {
                  !isStarter && actState === ActInProcess &&
                  (
                    <Block>
                      {
                        groupState === GroupInProcess &&
                        (<Button className="assistance-btn" style="margin:36px auto" onClick={this.joinGroup}>立即参团</Button>)
                      }
                      <Button className={groupState === GroupInProcess ? "set-btn" : "assistance-btn"} onClick={this.startMine}>发起我的拼团</Button>
                    </Block>
                  )
                }
              </ScrollView>

              <action-sheet hidden={!actionSheetVisible} bindchange={this.toggleActionVisible}>
                <action-sheet-item open-type="share">
                  <Button open-type="share" className='share__friend' onClick={this.toggleActionVisible}>分享给好友</Button>
                </action-sheet-item>
                <action-sheet-item>
                  <Button className='creat__img' onClick={this.shareMoments}>发送朋友圈</Button>
                </action-sheet-item>
                <action-sheet-cancel onClick={this.toggleActionVisible}>取消</action-sheet-cancel>
              </action-sheet>
            </View>
          )
        }
      </Block>
    )
  }
}
