import Taro, { Component } from '@tarojs/taro';
import './index.scss'

import { ROLE_CODE } from '@constants/user'
import { queryUserInfo, doUserSignin } from '@services/user'
import { connect } from '@tarojs/redux'
import Notice from '@components/Notice'

import * as actions from '@actions/user'
import Authorize from '@components/authorize'
@connect(({ user, city }) => ({ user, city }), { ...actions })
export default class Person extends Component {
  config = {
    navigationBarTitleText: '我的'
  }

  state = {
    isLogin: false,
    user: {},
    isAgent: false,//经纪人
    consultant: false,//置业顾问
    tourist: false,//普通用户
  }

  componentDidShow() {
    Taro.showLoading()
    this.loadUserInfo()
    Taro.hideLoading()
  }

  loadUserInfo() {
    queryUserInfo().then(user => {
      this.setState({
        user,
        phone: user.phone
      }, () => {
        if (user.personType != ROLE_CODE['CHANNEL_AGENT'] && user.personType != ROLE_CODE['ESTATE_AGENT'] && user.personType != 'Realty Consultant') {
          this.setState({ tourist: true, phone: user.phone })
        }
      })
    })
  }

  doSign() {
    const { user: { id, havaSigned } } = this.state
    if (havaSigned) {
      Taro.showToast({
        title: '你已经签到过了',
        icon: 'none'
      })
      return
    }

    doUserSignin({ id }).then(res => {
      Taro.showToast({
        title: '签到成功'
      })

      this.loadUserInfo()

      // App.zhuge.track('签到成功')
    })
  }

  toHomePage() {
    Taro.switchTab({
      url: '/pages/project/index'
    })
  }

  toShopPage() {
    Taro.switchTab({
      url: '/pages/shop/index'
    })
  }

  toClientPage() {
    const { user: { customerNum } } = this.state

    if (customerNum <= 0) {
      Taro.showToast({ title: '暂无客户', icon: 'none' })
      return
    }

    Taro.navigateTo({
      url: '/pages/person/myGuest/index'
    })
  }

  toFavor() {
    Taro.navigateTo({
      url: '/pages/person/favorite/index'
    })
  }
  toAgentClient() {
    Taro.navigateTo({
      url: '/pages/agent/client/index'
    })
  }
  toAssemble() {
    Taro.navigateTo({
      url: '/pages/activity/assemblePage'
    })
  }
  toAssistance() {
    Taro.navigateTo({
      url: '/pages/activity/assistancePage'
    })
  }
  toProfile() {
    Taro.navigateTo({
      url: '/pages/person/profile/index'
    })
  }
  toAgent() {
    Taro.navigateTo({
      url: '/pages/agent/index'
    })
  }
  toAgentInvitation() {
    Taro.navigateTo({
      url: '/pages/agent/invitation/index'
    })
  }
  toActivity() {
    Taro.navigateTo({
      url: '/pages/activity/index?from=mine'
    })
  }
  toRecord() {
    Taro.navigateTo({
      url: '/pages/shop/record/index'
    })
  }
  toToolkit() {
    Taro.navigateTo({
      url: '/pages/toolKit/index'
    })
  }
  toFeedback() {
    Taro.navigateTo({
      url: '/pages/person/feedback/index'
    })
  }

  getRoleName(type) {
    switch (type) {
      case ROLE_CODE['CONSULTANT']:
        this.setState({ consultant: true })
        return '置业顾问'
        break;
      case ROLE_CODE['ESTATE_AGENT']:
        this.setState({ isAgent: true })
        return '独立经纪人'
        break;
      case ROLE_CODE['CHANNEL_AGENT']:
        this.setState({ isAgent: true })
        return '渠道经纪人'
        break;
      default:
        return '普通用户'
        break;
    }
  }

  goShop() {
    Taro.switchTab({
      url: `/pages/shop/index`
    })
  }
  handleMore() {
    Taro.showModal({
      title: '温馨提示',
      content: '敬请期待'
    })
  }

  goPersonDetail() {
    const { user: { personType } } = this.state
    if (personType == ROLE_CODE['CHANNEL_AGENT'] || personType == ROLE_CODE['ESTATE_AGENT']) {
      Taro.navigateTo({
        url: '/pages/person/personDetail/index'
      })
    }

  }

  renderLogin() {
    return <Authorize></Authorize>
  }

  renderDetail() {
    const { user, isAgent, consultant, tourist } = this.state
    // const isConsultant = user.personType == ROLE_CODE['CONSULTANT']
    // const isConsultant = user.personType
    return (
      <View className="person">
        <Notice></Notice>
        <View className="info">
          <Image className="bg" src={require('@assets/mine/background.png')} mode='widthFix'></Image>
          <View className="content">
            <View className="info-block">
              <View className="avatar" onClick={this.goPersonDetail}>
                <Image className="info__headimg" src={user.avatar} />
                <View className="info-intro">{this.getRoleName(user.personType)}</View>
              </View>

              <View className="info-text" onClick={this.goPersonDetail}>
                <View className="info-text__name">{user.name ? user.name : user.nickname} {/* <Text className="iconfont icon-more"></Text> */}</View>
                <View className="info-text__intro">积分 {user.points || 0}</View>
              </View>
              <Navigator url={`/pages/person/spread/index`} className="tuiguang">
                <Image style="width:40px;height:36px" src={require('@assets/mine/tuiguangma.png')} ></Image>
                <View className="info-text__intro" style="margin:4px 0 0 4px">推广码</View>
              </Navigator>
            </View>
            {/* <View
              className={`sign__btn ${user.havaSigned && 'signed'}`}
              onClick={this.doSign}>{user.havaSigned ? '已打卡' : '打卡'}
            </View> */}

          </View>
          <View className='qiandao-con'>
            <Text className='qiandao-text'>签到得积分，积分兑好礼，马上去签到吧！</Text>
            <View className="qiandao-btn" onClick={this.doSign}>签到</View>

            {/* <Text className='integral-cont_btn' onClick={this.goShop}>去兑换</Text> */}

          </View>
        </View>
        <View>
          <View onClick={this.toAgent} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/homepage.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">我的主页</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toAgentClient} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/recommend.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">推荐客户</Text>
              <Text className="right-icon"></Text>
            </View>
          </View>
          <View onClick={this.toAgentInvitation} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/development.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">发展经纪人</Text>
              <Text className="right-icon"></Text>
            </View>
          </View>
          <View className='line'></View>
          <View onClick={this.toActivity} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/activities.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">我的活动</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toAssemble} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/regiment.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">我的拼团</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toAssistance} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/help.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">我的助力</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View className='line'></View>
          <View onClick={this.toFavor} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/collection.png')} ></Image>
            <View className="menu-maintext">
              <Text className="menu-name">我的收藏</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toRecord} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/exchange.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">兑换记录</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toProfile} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/profile.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">我的资料</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toToolkit} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/calculator.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">房贷计算器</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toToolkit} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/encyclopedia.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">购房百科</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
          <View onClick={this.toFeedback} className="menu-item-con">
            <Image className="left-icon" src={require('@assets/mine/feedback.png')} ></Image>
            <View className="menu-maintext">

              <Text className="menu-name">意见反馈</Text>
              <Text className="right-icon"></Text>
            </View>

          </View>
        </View>
        {/* <View className="list-item">
          <Image src={require('@assets/person/shouye.png')} className="icon" ></Image>
          <Text className='menu-item_txt'>我的主页</Text>
        </View> */}
        {/* <View className="menu menu1"> */}
        {/* 经纪人的主页 */}
        {/* {(user.personType == ROLE_CODE['ESTATE_AGENT'] || user.personType == ROLE_CODE['CHANNEL_AGENT']) && (<Navigator className="menu-item" hover-class="none" url={`/pages/agent/index`}>
            <Image src={require('@assets/person/shouye.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的主页</Text>
          </Navigator>)} */}
        {/* 置业顾问主页 */}
        {/* {user.personType == 'Realty Consultant' && (<Navigator className="menu-item" hover-class="none" url={`/pages/card/index?id=${user.id}`}>
            <Image src={require('@assets/person/shouye.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的主页</Text>
          </Navigator>)} */}

        {/* 经纪人推荐客户 */}
        {/* {(user.personType == ROLE_CODE['ESTATE_AGENT'] || user.personType == ROLE_CODE['CHANNEL_AGENT']) && (<Navigator className="menu-item" hover-class="none" url={`/pages/agent/client/index`}>
            <Image src={require('@assets/person/wode.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>推荐客户</Text>
          </Navigator>)} */}



        {/* 游客主页 */}
        {/* {(user.personType == ROLE_CODE['CUSTOMER'] || !user.personType) && (<Navigator className="menu-item" hover-class="none" url={`/pages/agent/become/index`}>
            <Image src={require('@assets/person/shouye.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>经纪人</Text>
          </Navigator>)} */}


        {/* 置业顾问 */}
        {/* {user.personType == 'Realty Consultant' && (<View className='menu-item' onClick={this.toClientPage}>
            <Image src={require('@assets/person/kehu.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的客户</Text>
          </View>)} */}

        {/* <Navigator className='menu-item' hover-class="none" url="/pages/person/feedback/index">
            <Image src={require('@assets/person/fankui.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>意见反馈</Text>
          </Navigator> */}

        {/* <Navigator className='menu-item' hover-class="none" url="/pages/shop/record/index">
            <Image src={require('@assets/person/shijian.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>兑换记录</Text>
          </Navigator> */}

        {/* <Navigator className='menu-item' hover-class="none" url="/pages/activity/index?from=mine">
            <Image src={require('@assets/person/huodong.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的活动</Text>
          </Navigator> */}

        {/* <View className='menu-item' onClick={this.toFavor}>
            <Image src={require('@assets/person/shou.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的收藏</Text>
          </View>
        */}

        {/* 经纪人我的邀请 */}
        {/* {(user.personType == ROLE_CODE['ESTATE_AGENT'] || user.personType == ROLE_CODE['CHANNEL_AGENT']) && (<Navigator className="menu-item" hover-class="none" url={`/pages/agent/invitation/index`}>
            <Image src={require('@assets/person/yaoqing.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>发展经纪人</Text>
          </Navigator>)} */}
        {/* 经纪人/置业顾问推广码 */}
        {/* {(user.personType == ROLE_CODE['ESTATE_AGENT'] || user.personType == ROLE_CODE['CHANNEL_AGENT'] || user.personType == ROLE_CODE['CONSULTANT']) && (<Navigator className="menu-item" hover-class="none" url={`/pages/person/spread/index`}>
            <Image src={require('@assets/tui.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>我的推广码</Text>
          </Navigator>)}
        </View> */}
        {/* VIP积分 */}
        {/* <View className='integral'>
          <Image src={require('@assets/person/vip.png')} className='integral-img' mode="widthFix" onClick={this.doSign}></Image>
          <Image src={require('@assets/person/fanhui.png')} className='goto_btn' mode="widthFix"></Image>
        </View> */}
        {/* <View className='line'></View>
        <View className='menu menu2'>
          <View className='menu-tit'>我的服务</View>
          <Navigator className='menu-item' hover-class="none" url="/pages/toolKit/index?from=mine">
            <Image src={require('@assets/person/jisuanqi.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>房贷计算</Text>
          </Navigator> */}
        {/* <Navigator className='menu-item' hover-class="none" url="/pages/policy/index?from=mine">
            <Image src={require('@assets/person/zheng.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>购房政策</Text>
          </Navigator> */}
        {/* <View className='menu-item' onClick={this.handleMore}>
            <Image src={require('@assets/person/more.png')} className='menu-item_img' mode="widthFix"></Image>
            <Text className='menu-item_txt'>敬请期待</Text>
          </View>
        </View> */}
      </View>
    );
  }

  render() {
    const { phone } = this.state.user
    return (
      <View className='wrap'>
        {phone && this.renderDetail()}
        {!phone && this.renderLogin()}
      </View>
    )
  }
}
