import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import { AtImagePicker } from 'taro-ui'
import { getDocumentVerify, commitDocumentVerify, editDocumentVerify } from '@services/user'
import { uploadFiles } from '@utils/request'

import "taro-ui/dist/style/components/image-picker.scss";
import "taro-ui/dist/style/components/icon.scss";

// import { connect } from '@tarojs/redux'


// @connect(state => state.city)
export default class Profile extends Component {
  config = {
    navigationBarTitleText: '我的资料'
  }

  state = {
    files: [],
    auditStatus: 0,
    documentVerifyId: '',

  }
  // 审核状态   0审核中  1审核通过  2审核不通过 3未审核
  componentDidMount() {
    this.getProfile()
  }

  getProfile() {
    Taro.showLoading()
    getDocumentVerify().then(res => {
      if (!res) {
        this.setState({
          auditStatus: 3,
        })
      } else {
        this.setState({
          files: res.imgList.map(x => ({ url: x.img })),
          auditStatus: res.verifyStatus,
          // resData:res,
          documentVerifyId: res.documentVerifyId,
        })
      }

      Taro.hideLoading()
    }).catch((err) => {
      Taro.hideLoading()
      setTimeout(() => {
        Taro.showToast({ icon: 'none', title: '获取信息失败' });
      }, 500)

    });
  }

  onChange(files) {
    const filePaths = files.map(x => x.file.path)
    uploadFiles(filePaths).then((res) => {
      this.setState({
        files: res.map(x => ({ url: x}))
      })
    })
  }
  onFail(mes) {
    console.log(mes)
  }
  onImageClick(index, file) {
    console.log(index, file)
  }

  // 提交图片审核
  commitBtn() {
    console.log(this.state.auditStatus, "this.state.auditStatus")
    if (this.state.files.length == 0) {
      Taro.showToast({ icon: 'none', title: '请先上传图片' });
    } else if (this.state.auditStatus != 3) {
      let imgList = []
      let fileList = this.state.files
      fileList.map((item, index) => {
          let newObj = {}
          newObj.img = item.url,
          newObj.sort = index
          imgList.push(newObj)
        }
      )

      const payload = {
        imgList,
        documentVerifyId: this.state.documentVerifyId
      }

      editDocumentVerify(payload).then(res => {
        this.setState({
          files: res.imgList.map(x => ({url: x.img})),
          auditStatus: res.verifyStatus
        })
        Taro.showToast({ icon: 'none', title: '提交成功' });
      }).catch((err) => {
        Taro.showToast({ icon: 'none', title: err.errMsg || '提交失败' });
        console.error(err);
      });

    } else {

      let imgList = []
      let fileList = this.state.files
      fileList.map((item, index) => {
        let newObj = {}
        newObj.img = item.url
        newObj.sort = index
        imgList.push(newObj)
      })

      commitDocumentVerify(imgList).then(res => {
        this.setState({
          files: res.imgList.map(x => ({url: x.img})),
          auditStatus: res.verifyStatus
        })
        Taro.showToast({ icon: 'none', title: '提交成功' });

      }).catch((err) => {
        Taro.showToast({ icon: 'none', title: err.errMsg || '提交失败' });
        console.error(err);
      });
    }
  }


  render() {


    return (
      <View className="profile-page">
        <View className="tip">
          建议上传相关购房资格等相关资料,最多上传8张,
        </View>
        <View className="tip">
          审核通过后将获取更多积分、兑换好礼~
        </View>
        {this.state.auditStatus == 1 &&
          <View className="commit-text" >审核通过,快去查看积分吧~</View>
        }

        <AtImagePicker
          showAddBtn={(this.state.files.length < 8 && this.state.auditStatus == 2) || (this.state.auditStatus == 3 && this.state.files.length < 8)}
          length={2}
          mode="scaleToFill"
          files={this.state.files}
          onChange={this.onChange.bind(this)}
          onFail={this.onFail.bind(this)}
          onImageClick={this.onImageClick.bind(this)}
        />
        {this.state.auditStatus == 2 &&
          <View className="commit-text" >审核未通过,请重新提交!</View>
        }

        {(this.state.auditStatus == 2 || this.state.auditStatus == 3) &&
          <View className="commit-btn" onClick={this.commitBtn}>提交审核</View>
        }
        {this.state.auditStatus == 0 &&
          <View className="commit-text" >审核中</View>
        }

      </View>
    )
  }
}
