import Taro, { Component } from '@tarojs/taro';
import './index.scss'

import { connect } from '@tarojs/redux'
import * as actions from '@actions/project'
import { savePoint, updatePoint } from '@services/common'
@connect(state => state.project, { ...actions })
export default class Index extends Component {

  config = {
    navigationBarTitleText: '相册信息'
  }

  state = {
    recordId: null
  }


  componentWillMount() {
    const { id = '369b7d7e5bc6e6b91f2e8f5e775035e2' } = this.$router.params
    const { projectDetail: { buildingId }, dispatchProjectDetail } = this.props

    if (!buildingId) {
      dispatchProjectDetail(id)
    }

    savePoint({
      event: 'album',
      eventType: 'building',
      propertyName: '相册信息',
      data: '{}'
    }).then(res => {
      this.setState({
        recordId: res.recordId
      })
      console.log('相册信息')
    })
  }
  componentWillUnmount() {
    const { recordId } = this.state
    updatePoint(recordId).then(res => { })
  }
  // 图片预览
  previewImage(cur, urls) {
    wx.previewImage({
      current: cur, // 当前显示图片的http链接   
      urls: urls // 需要预览的图片http链接列表   
    })
  }

  render() {
    const { projectDetail: { buildingImg = [], buildingApartment = [], mapImg, poster } } = this.props
    const liveImgs = buildingImg.map(img => img.url)
    let hxImgs = buildingApartment.filter(item => item.apartmentType === 'apart')
    hxImgs = hxImgs.reduce((prev, cur) => {
      prev = prev.concat(cur.buildingImgList)
      return prev
    }, [])
    let _hxImgUrls = hxImgs.map(img => img.url)

    let photosImgs = buildingApartment.filter(item => item.apartmentType === 'photo')
    photosImgs = photosImgs.reduce((prev, cur) => {
      prev = prev.concat(cur.buildingImgList)
      return prev
    }, [])
    let _photosImgs = photosImgs.map(img => img.url)

    return (
      <View className='photos'>
        <ScrollView>
          <View className='photos__item'>
            <View className='photos__title'>效果图</View>
            {photosImgs.map((item, index) => (
              <Image className='photos__item-img' src={item.url} mode="aspectFill" key={item.imgId} onClick={this.previewImage.bind(this, item.url, _photosImgs)}></Image>
            ))}
          </View>

          <View className='photos__item'>
            <View className='photos__item-title'>实景图</View>
            {liveImgs.map((item, index) => (
              <Image className='photos__item-img' src={item} mode="aspectFill" key={index} onClick={this.previewImage.bind(this, item, liveImgs)}></Image>
            ))}
          </View>

          <View className='photos__item'>
            <View className='photos__item-title'>户型图</View>
            {hxImgs.map((item, index) => (
              <Image className='photos__item-img' src={item.url} mode="aspectFill" key={item.imgId} onClick={this.previewImage.bind(this, item.url, _hxImgUrls)}></Image>
            ))}
          </View>

          <View className='photos__item'>
            <View className='photos__item-title'>地图</View>
            <Image className='photos__item-img' src={mapImg} mode="aspectFill" onClick={this.previewImage.bind(this, mapImg, [mapImg])}></Image>
          </View>
        </ScrollView>
      </View>
    );
  }
}