import Taro, { Component } from '@tarojs/taro';
import { getWindowHeight } from '@utils/style'
import { AtTabs, AtTabsPane } from 'taro-ui'
import "taro-ui/dist/style/components/tabs.scss"
import './index.scss'

// import Search from '@components/search'
import Banner from './banner'
import ready from '@utils/ready'
// import { ROLE_CODE } from '@constants/user'
import { queryBanners } from '@services/common'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/shop'
// import { queryUserInfo, doUserSignin } from '@services/user'

// import getUserPhone from '@utils/getUserPhone'
import Authorize from '@components/authorize'

@connect(({ user, shop, city }) => ({ ...user, ...shop, ...city }), { ...actions })
export default class Shop extends Component {
  config = {
    navigationBarTitleText: '积分商城'
  }

  state = {
    keywords: '',
    bannerList: [
      'https://estateagents.oss-cn-shanghai.aliyuncs.com/images/banner/1.jpg',
      'https://estateagents.oss-cn-shanghai.aliyuncs.com/images/banner/2.jpg',
      'https://estateagents.oss-cn-shanghai.aliyuncs.com/images/banner/3.jpg',
      'https://estateagents.oss-cn-shanghai.aliyuncs.com/images/banner/4.jpg',
      'https://estateagents.oss-cn-shanghai.aliyuncs.com/images/banner/5.jpg'
    ],
    user: {},
    cityName: ''
  }

  componentDidShow() {
    Taro.showLoading()
    ready.queue(() => {
      this.loadBannerList()
      this.loadList()
      //    this.loadCity()
      // this.loadUserInfo()
    })
    Taro.hideLoading()
  }

  // loadUserInfo() {
  //   queryUserInfo().then(user => {
  //     this.setState({
  //       user
  //     })
  //   })
  // }


  //loadCity(){
  //  const {cityName}=this.state
  //  if(!cityName){
  //    const lat=Taro.getStorageSync('lat')
  //    const lon=Taro.getStorageSync('lon')
  //    const params={
  //      lat,
  //      lon
  //    }
  //    const payload=params
  //    this.props.dispatchPointsAddress(payload).then(res => {
  //      const city=res.cityName
  //      this.setState({
  //        cityName:city
  //      })
  //    })
  //  }
  //}


  loadBannerList() {
    const payload = {
      showPosition: 'mall'
    }
    queryBanners('banner', payload).then(res => {
      this.setState({
        bannerList: res || []
      })
    })
  }

  onSearch(val) {
    // App.zhuge.track('搜索商品', {
    //   '商品名称': val
    // })
    this.setState({
      keywords: val,
    }, this.loadList)
  }

  loadList() {
    // const payload = { buildingId: '369b7d7e5bc6e6b91f2e8f5e775035e2' }
    Taro.showLoading()
    this.props.dispatchGoodsList().then(res => {
      Taro.hideLoading()
    })
  }

  onViewDetail(item) {
    Taro.navigateTo({
      url: `/pages/shop/detail/index?id=${item.goodsId}`
    })
  }

  goPointRecords() {
    const { person: { points } } = this.props.userInfo
    Taro.navigateTo({
      url: `/pages/shop/integralDetail/index?points=` + points
    })
  }

  goPointRule() {
    Taro.navigateTo({
      url: `/pages/shop/rule/index`
    })
  }

  handleLocationClick() {
    Taro.navigateTo({
      url: `/pages/city/index`
    })
  }
  doSign() {
    const { user: { id, havaSigned } } = this.state
    if (havaSigned) {
      Taro.showToast({
        title: '你已经签到过了',
        icon: 'none'
      })
      return
    }

    doUserSignin({ id }).then(res => {
      Taro.showToast({
        title: '签到成功'
      })

      this.loadUserInfo()

    })
  }


  renderLogin() {
    return <Authorize></Authorize>
  }
  state = {
    current: 0,
  }

  handleClick(value) {
    this.setState({
      current: value
    })
  }

  renderGoods() {
    const { goods: { records = [] } } = this.props

    return (

      <View className="list__wrap">
        <AtTabs current={this.state.current} tabList={[{ title: '热门活动' }, { title: '最新资讯' }]} onClick={this.handleClick.bind(this)}>
          <AtTabsPane current={this.state.current} index={0} >
            <View >

              {
                records.map(item => (
                  <View className="item" key={item.goodsId} onClick={this.onViewDetail.bind(this, item)}>
                    <Image className="item__img" src={item.imgUrl} />
                    <View className="item__title">{item.goodsName}</View>
                    <View className="item__des">
                      <View>
                        剩余数量{item.inventory}
                      </View>
                      <View >
                        <Text className="item__jifen">{item.pointPrice}</Text>积分
                </View>
                    </View>

                  </View>
                ))
              }

            </View>
          </AtTabsPane>
          <AtTabsPane current={this.state.current} index={1}>
            <View >
              123
          </View>
          </AtTabsPane>
        </AtTabs>
      </View>


    )
  }

  renderDetail() {
    // const { user } = this.state
    const { userInfo: { person }, curCity } = this.props
    return (
      <View className="page">
        {/* <Search placeholder="请输入要搜索的商品名称" onSearch={this.onSearch} /> */}
        <ScrollView
          scrollY
          scroll-with-animation
          enable-back-to-top
          className="list"
          style={{
            height: getWindowHeight()
          }}>
          <View className="user_box">
            <View className="user_con">
              <Image className="bg" src={require('@assets/shop/background.jpg')} ></Image>
              <Image className="user__left__headimg" src={person.avatarurl} />
              <View className='user__left__name'>{person.nickname}</View>
              <View className="qiandao__btn" onClick={this.doSign}>签到</View>
              <View className='message'>
                <View className='message__left'>
                  <View className='user__jifen'>
                    积分<Text className='user__jifen__right'>{person.points || 0}</Text>
                  </View>
                  <View className='message__left__btn' onClick={this.goPointRule.bind(this)}>
                    <Image className="message__left__img" src={require('@assets/shop/rule.png')} />
                    <View className='message__left__word'>积分规则</View>
                  </View>
                  <View className='message__left__btn' onClick={this.goPointRecords.bind(this)}>
                    <Image className="message__left__img" src={require('@assets/shop/liebiao.png')} />
                    <View className='message__left__word'>积分明细</View>
                  </View>

                </View>
                {/* <View className='message__right' onClick={this.handleLocationClick.bind(this)}>
                <Image className="message__right__img" src={require('@assets/shop/address.png')} />
                <View className='message__right__word'>{curCity.name}</View>
              </View> */}
              </View>
            </View>
          </View>


          {/* <View className="hot_title">热门商品</View> */}
          <Banner list={this.state.bannerList} indicatorDots={false}></Banner>

          {this.renderGoods()}
        </ScrollView>
      </View >
    );
  }

  render() {
    const { person: { personType } } = this.props.userInfo
    //const { person: { phone } } = this.props.userInfo
    // const isDrift = personType === ROLE_CODE['DRIFT']

    return (
      <View className='wrap'>
        {personType == 'drift' ? this.renderLogin() : this.renderDetail()}
      </View>
    )
  }
}
